.. _documentation: https://mincepy.readthedocs.org/
.. _object-relational mapper: https://en.wikipedia.org/wiki/Object-relational_mapping
.. _data mapper pattern: https://en.wikipedia.org/wiki/Data_mapper_pattern

mincePy
=======

.. image:: https://codecov.io/gh/muhrin/mincepy/branch/develop/graph/badge.svg
    :target: https://codecov.io/gh/muhrin/mincepy
    :alt: Coverage

.. image:: https://travis-ci.com/muhrin/mincepy.svg?branch=master
    :target: https://travis-ci.com/github/muhrin/mincepy
    :alt: Travis CI

.. image:: https://img.shields.io/pypi/v/mincepy.svg
    :target: https://pypi.python.org/pypi/mincepy/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/wheel/mincepy.svg
    :target: https://pypi.python.org/pypi/mincepy/

.. image:: https://img.shields.io/pypi/pyversions/mincepy.svg
    :target: https://pypi.python.org/pypi/mincepy/

.. image:: https://img.shields.io/pypi/l/mincepy.svg
    :target: https://pypi.python.org/pypi/mincepy/


mincePy: move the database to one side and let your objects take centre stage.

MincePy is an `object-relational mapper`_ (ORM) using the `data mapper pattern`_ designed specifically for computational
and data science.  What does this all mean??  It's simple really, it means you can store, find, get the history of and
annotate any of your python objects either in your local database or one shared with your collaborators.



See `documentation`_ for more information.
